@@ -1,15 +1,15 @@
 """Airzone library common code."""
 from __future__ import annotations
 
-from dataclasses import dataclass
-from enum import Enum
+from enum import IntEnum
 
 
-class AirzoneStages(int, Enum):
+class AirzoneStages(IntEnum):
     """Airzone stages."""
 
     UNKNOWN = -1
 
+    EMPTY = 0
     Air = 1
     Radiant = 2
     Combined = 3
@@ -18,6 +18,10 @@ class AirzoneStages(int, Enum):
     def _missing_(cls, value):
         return cls.UNKNOWN
 
+    def exists(self) -> bool:
+        """Return if Airzone Stage exits."""
+        return self.value != self.EMPTY
+
     def to_list(self) -> list[AirzoneStages]:
         """Convert AirzoneStages value to list."""
         if self.value == self.Combined:
@@ -27,15 +31,7 @@ class AirzoneStages(int, Enum):
         return []
 
 
-@dataclass
-class ConnectionOptions:
-    """Airzone options for connection."""
-
-    ip_address: str
-    port: int
-
-
-class OperationMode(int, Enum):
+class OperationMode(IntEnum):
     """Airzone operation modes."""
 
     UNKNOWN = -1
@@ -52,7 +48,7 @@ class OperationMode(int, Enum):
         return cls.UNKNOWN
 
 
-class SystemType(int, Enum):
+class SystemType(IntEnum):
     """Airzone System Types."""
 
     UNKNOWN = -1
@@ -84,14 +80,14 @@ class SystemType(int, Enum):
         return models[self.value]
 
 
-class TemperatureUnit(int, Enum):
+class TemperatureUnit(IntEnum):
     """Airzone temperature units."""
 
     CELSIUS = 0
     FAHRENHEIT = 1
 
 
-class ThermostatType(int, Enum):
+class ThermostatType(IntEnum):
     """Airzone Thermostat Types."""
 
     UNKNOWN = -1
@@ -128,7 +124,7 @@ class ThermostatType(int, Enum):
         return models[self.value]
 
 
-class WebServerInterface(int, Enum):
+class WebServerInterface(IntEnum):
     """Airzone WebServer Interface type."""
 
     UNKNOWN = -1
@@ -139,3 +135,25 @@ class WebServerInterface(int, Enum):
     @classmethod
     def _missing_(cls, value):
         return cls.UNKNOWN
+
+
+class WebServerType(IntEnum):
+    """Airzone WebServer Types."""
+
+    UNKNOWN = -1
+
+    AIRZONE = 1
+    AIDOO = 2
+
+    @classmethod
+    def _missing_(cls, value):
+        return cls.UNKNOWN
+
+    def __str__(self) -> str:
+        """Convert WebServerType value to string."""
+        models: dict[int, str] = {
+            self.UNKNOWN: "Unknown",
+            self.AIRZONE: "Airzone WebServer",
+            self.AIDOO: "Aidoo WebServer",
+        }
+        return models[self.value]
