@@ -9,6 +9,7 @@ API_COOL_MIN_TEMP = "coolmintemp"
 API_COOL_SET_POINT = "coolsetpoint"
 API_DATA = "data"
 API_DOUBLE_SET_POINT = "double_sp"
+API_ERROR = "error"
 API_ERRORS = "errors"
 API_FLOOR_DEMAND = "floor_demand"
 API_HEAT_MAX_TEMP = "heatmaxtemp"
@@ -44,14 +45,29 @@ API_WEBSERVER = "webserver"
 API_WIFI = "wifi"
 API_WIFI_CHANNEL = "wifi_channel"
 API_WIFI_QUALITY = "wifi_quality"
-API_WIFI_SIGNAL = "wifi_signal"
+API_WIFI_RSSI = "wifi_rssi"
+API_WS_AIDOO = "ws_aidoo"
+API_WS_AZ = "ws_az"
+API_WS_FIRMWARE = "firmware"
+API_WS_TYPE = "ws_type"
 API_ZONE_ID = "zoneID"
 
 API_ERROR_LOW_BATTERY = "Low battery"
+API_ERROR_METHOD_NOT_SUPPORTED = "Method not provided or not supported"
+API_ERROR_REQUEST_MALFORMED = "request malformed"
+API_ERROR_SYSTEM_ID_NOT_AVAILABLE = "systemid not avaiable"
 API_ERROR_SYSTEM_ID_OUT_RANGE = "systemid out of range"
 API_ERROR_ZONE_ID_NOT_AVAILABLE = "zoneid not avaiable"
 API_ERROR_ZONE_ID_OUT_RANGE = "zoneid out of range"
 
+API_DOUBLE_SET_POINT_PARAMS = {
+    API_COOL_MAX_TEMP,
+    API_COOL_MIN_TEMP,
+    API_COOL_SET_POINT,
+    API_HEAT_MAX_TEMP,
+    API_HEAT_MIN_TEMP,
+    API_HEAT_SET_POINT,
+}
 API_SYSTEM_PARAMS = [
     API_MODE,
     API_SPEED,
@@ -66,23 +82,25 @@ API_ZONE_PARAMS = [
     API_SET_POINT,
 ]
 
-AZD_AIR_DEMAND = "air_demand"
-AZD_BATTERY_LOW = "battery_low"
-AZD_COLD_STAGE = "cold_stage"
-AZD_COLD_STAGES = "cold_stages"
-AZD_COOL_TEMP_MAX = "cool_temp_max"
-AZD_COOL_TEMP_MIN = "cool_temp_min"
-AZD_COOL_TEMP_SET = "cool_temp_set"
+AZD_AIR_DEMAND = "air-demand"
+AZD_BATTERY_LOW = "battery-low"
+AZD_COLD_STAGE = "cold-stage"
+AZD_COLD_STAGES = "cold-stages"
+AZD_COOL_TEMP_MAX = "cool-temp-max"
+AZD_COOL_TEMP_MIN = "cool-temp-min"
+AZD_COOL_TEMP_SET = "cool-temp-set"
 AZD_DEMAND = "demand"
-AZD_DOUBLE_SET_POINT = "double_set_point"
+AZD_DOUBLE_SET_POINT = "double-set-point"
+AZD_ENERGY = "energy"
 AZD_ERRORS = "errors"
 AZD_FIRMWARE = "firmware"
-AZD_FLOOR_DEMAND = "floor_demand"
-AZD_HEAT_TEMP_MAX = "heat_temp_max"
-AZD_HEAT_TEMP_MIN = "heat_temp_min"
-AZD_HEAT_TEMP_SET = "heat_temp_set"
-AZD_HEAT_STAGE = "heat_stage"
-AZD_HEAT_STAGES = "heat_stages"
+AZD_FULL_NAME = "full-name"
+AZD_FLOOR_DEMAND = "floor-demand"
+AZD_HEAT_TEMP_MAX = "heat-temp-max"
+AZD_HEAT_TEMP_MIN = "heat-temp-min"
+AZD_HEAT_TEMP_SET = "heat-temp-set"
+AZD_HEAT_STAGE = "heat-stage"
+AZD_HEAT_STAGES = "heat-stages"
 AZD_HUMIDITY = "humidity"
 AZD_ID = "id"
 AZD_INTERFACE = "interface"
@@ -93,27 +111,29 @@ AZD_MODEL = "model"
 AZD_MODES = "modes"
 AZD_NAME = "name"
 AZD_ON = "on"
-AZD_POWER = "power"
 AZD_PROBLEMS = "problems"
 AZD_SPEED = "speed"
 AZD_SPEEDS = "speeds"
 AZD_SYSTEM = "system"
 AZD_SYSTEMS = "systems"
-AZD_SYSTEMS_NUM = "num_systems"
+AZD_SYSTEMS_NUM = "num-systems"
 AZD_TEMP = "temp"
-AZD_TEMP_MAX = "temp_max"
-AZD_TEMP_MIN = "temp_min"
-AZD_TEMP_SET = "temp_set"
-AZD_TEMP_UNIT = "temp_unit"
-AZD_THERMOSTAT_FW = "thermostat_fw"
-AZD_THERMOSTAT_MODEL = "thermostat_model"
-AZD_THERMOSTAT_RADIO = "thermostat_radio"
+AZD_TEMP_MAX = "temp-max"
+AZD_TEMP_MIN = "temp-min"
+AZD_TEMP_SET = "temp-set"
+AZD_TEMP_UNIT = "temp-unit"
+AZD_THERMOSTAT_FW = "thermostat-fw"
+AZD_THERMOSTAT_MODEL = "thermostat-model"
+AZD_THERMOSTAT_RADIO = "thermostat-radio"
 AZD_WEBSERVER = "webserver"
-AZD_WIFI_CHANNEL = "wifi_channel"
-AZD_WIFI_QUALITY = "wifi_quality"
-AZD_WIFI_SIGNAL = "wifi_signal"
+AZD_WIFI_CHANNEL = "wifi-channel"
+AZD_WIFI_QUALITY = "wifi-quality"
+AZD_WIFI_RSSI = "wifi-rssi"
 AZD_ZONES = "zones"
-AZD_ZONES_NUM = "num_zones"
+AZD_ZONES_NUM = "num-zones"
+
+DEFAULT_PORT = 3000
+DEFAULT_SYSTEM_ID = 0
 
 ERROR_SYSTEM = "system"
 ERROR_ZONE = "zone"
